==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/SubscriptionReceiverValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The subscription role receiver value.
 * @property role The role of the notification receiver.
 * @property subscriptionId The subscription id of the notification receiver.
 * @property subscriptionName The subscription name of the notification receiver.
 */
public data class SubscriptionReceiverValueArgs(
    public val role: Output<String>? = null,
    public val subscriptionId: Output<String>? = null,
    public val subscriptionName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs> {
    override fun toJava(): com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs =
        com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs.builder()
            .role(role?.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.applyValue({ args0 -> args0 }))
            .subscriptionName(subscriptionName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SubscriptionReceiverValueArgs].
 */
@PulumiTagMarker
public class SubscriptionReceiverValueArgsBuilder internal constructor() {
    private var role: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var subscriptionName: Output<String>? = null

    /**
     * @param value The role of the notification receiver.
     */
    @JvmName("uwuwwfhikjajcqcj")
    public suspend fun role(`value`: Output<String>) {
        this.role = value
    }

    /**
     * @param value The subscription id of the notification receiver.
     */
    @JvmName("fiblevqjxihfuncn")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value The subscription name of the notification receiver.
     */
    @JvmName("ycushkoygtbriayb")
    public suspend fun subscriptionName(`value`: Output<String>) {
        this.subscriptionName = value
    }

    /**
     * @param value The role of the notification receiver.
     */
    @JvmName("ximantphfapatvie")
    public suspend fun role(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The subscription id of the notification receiver.
     */
    @JvmName("grbvlayepondrgxv")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value The subscription name of the notification receiver.
     */
    @JvmName("juebtsxnvftmgxfs")
    public suspend fun subscriptionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionName = mapped
    }

    internal fun build(): SubscriptionReceiverValueArgs = SubscriptionReceiverValueArgs(
        role = role,
        subscriptionId = subscriptionId,
        subscriptionName = subscriptionName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/SubscriptionReceiverValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The subscription role receiver value.
 * @property role The role of the notification receiver.
 * @property subscriptionId The subscription id of the notification receiver.
 * @property subscriptionName The subscription name of the notification receiver.
 */
public data class SubscriptionReceiverValueArgs(
    public val role: Output<String>? = null,
    public val subscriptionId: Output<String>? = null,
    public val subscriptionName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs> {
    override fun toJava(): com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs =
        com.pulumi.azurenative.testbase.inputs.SubscriptionReceiverValueArgs.builder()
            .role(role?.applyValue({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.applyValue({ args0 -> args0 }))
            .subscriptionName(subscriptionName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SubscriptionReceiverValueArgs].
 */
@PulumiTagMarker
public class SubscriptionReceiverValueArgsBuilder internal constructor() {
    private var role: Output<String>? = null

    private var subscriptionId: Output<String>? = null

    private var subscriptionName: Output<String>? = null

    /**
     * @param value The role of the notification receiver.
     */
    @JvmName("mhrdfjqosuyjuape")
    public suspend fun role(`value`: Output<String>) {
        this.role = value
    }

    /**
     * @param value The subscription id of the notification receiver.
     */
    @JvmName("mpemjtqlfmolkobr")
    public suspend fun subscriptionId(`value`: Output<String>) {
        this.subscriptionId = value
    }

    /**
     * @param value The subscription name of the notification receiver.
     */
    @JvmName("leniwluncbrysais")
    public suspend fun subscriptionName(`value`: Output<String>) {
        this.subscriptionName = value
    }

    /**
     * @param value The role of the notification receiver.
     */
    @JvmName("pgvemmdjhpvxabht")
    public suspend fun role(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The subscription id of the notification receiver.
     */
    @JvmName("sqianvibdkwxgqrc")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionId = mapped
    }

    /**
     * @param value The subscription name of the notification receiver.
     */
    @JvmName("jbufeffroeplxsae")
    public suspend fun subscriptionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subscriptionName = mapped
    }

    internal fun build(): SubscriptionReceiverValueArgs = SubscriptionReceiverValueArgs(
        role = role,
        subscriptionId = subscriptionId,
        subscriptionName = subscriptionName,
    )
}
